summaryrefslogtreecommitdiffstats
path: root/kate
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit1dcbbe821d337f155c5835aa372db3cadcc31ed8 (patch)
treea0b305d9d9334acfe296542840e8e05fbc63bae9 /kate
parent9c49a74a165b8535c28ccbb2fad37334989b2fc7 (diff)
downloadtdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.tar.gz
tdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kate')
-rw-r--r--kate/part/katebuffer.cpp8
-rw-r--r--kate/part/katebuffer.h2
-rw-r--r--kate/part/katedocument.cpp6
-rw-r--r--kate/part/katedocument.h2
-rw-r--r--kate/part/katefactory.cpp10
-rw-r--r--kate/part/katefactory.h4
-rw-r--r--kate/part/katehighlight.h4
-rw-r--r--kate/part/kateschema.cpp8
-rw-r--r--kate/part/kateschema.h4
-rw-r--r--kate/part/kateviewhelpers.cpp4
-rw-r--r--kate/part/test_regression.cpp2
11 files changed, 27 insertions, 27 deletions
diff --git a/kate/part/katebuffer.cpp b/kate/part/katebuffer.cpp
index 3325c69e9..05af27ff8 100644
--- a/kate/part/katebuffer.cpp
+++ b/kate/part/katebuffer.cpp
@@ -849,7 +849,7 @@ void KateBuffer::setTabWidth (uint w)
m_tabWidth = w;
if (m_highlight && m_highlight->foldingIndentationSensitive())
- tqinvalidateHighlighting();
+ invalidateHighlighting();
}
}
@@ -881,7 +881,7 @@ void KateBuffer::setHighlight(uint hlMode)
m_highlight = h;
if (tqinvalidate)
- tqinvalidateHighlighting();
+ invalidateHighlighting();
// inform the document that the hl was really changed
// needed to update attributes and more ;)
@@ -889,7 +889,7 @@ void KateBuffer::setHighlight(uint hlMode)
}
}
-void KateBuffer::tqinvalidateHighlighting()
+void KateBuffer::invalidateHighlighting()
{
m_lineHighlightedMax = 0;
m_lineHighlighted = 0;
@@ -977,7 +977,7 @@ bool KateBuffer::doHighlight (KateBufBlock *buf, uint startLine, uint endLine, b
{
if (KateHlManager::self()->resetDynamicCtxs())
{
- kdDebug (13020) << "HL tqinvalidated - too many dynamic contexts ( >= " << m_maxDynamicContexts << ")" << endl;
+ kdDebug (13020) << "HL invalidated - too many dynamic contexts ( >= " << m_maxDynamicContexts << ")" << endl;
// avoid recursive invalidation
KateHlManager::self()->setForceNoDCReset(true);
diff --git a/kate/part/katebuffer.h b/kate/part/katebuffer.h
index 43430ec2c..450f260ab 100644
--- a/kate/part/katebuffer.h
+++ b/kate/part/katebuffer.h
@@ -591,7 +591,7 @@ class KateBuffer : public TQObject
/**
* Invalidate highlighting of whole buffer.
*/
- void tqinvalidateHighlighting();
+ void invalidateHighlighting();
KateCodeFoldingTree *foldingTree () { return &m_regionTree; };
diff --git a/kate/part/katedocument.cpp b/kate/part/katedocument.cpp
index dbab1ef08..cc6a462ac 100644
--- a/kate/part/katedocument.cpp
+++ b/kate/part/katedocument.cpp
@@ -91,7 +91,7 @@ class KatePartPluginItem
// KateDocument Constructor
//
KateDocument::KateDocument ( bool bSingleViewMode, bool bBrowserView,
- bool bReadOnly, TQWidget *tqparentWidget,
+ bool bReadOnly, TQWidget *parentWidget,
const char *widgetName, TQObject *parent, const char *name)
: Kate::Document(parent, name),
m_plugins (KateFactory::self()->plugins().count()),
@@ -214,7 +214,7 @@ KateDocument::KateDocument ( bool bSingleViewMode, bool bBrowserView,
// if single view mode, like in the konqui embedding, create a default view ;)
if ( m_bSingleViewMode )
{
- KTextEditor::View *view = createView( tqparentWidget, widgetName );
+ KTextEditor::View *view = createView( parentWidget, widgetName );
insertChildClient( view );
view->show();
setWidget( view );
@@ -2872,7 +2872,7 @@ void KateDocument::makeAttribs(bool needInvalidate)
m_views.tqat(z)->renderer()->updateAttributes ();
if (needInvalidate)
- m_buffer->tqinvalidateHighlighting();
+ m_buffer->invalidateHighlighting();
tagAll ();
}
diff --git a/kate/part/katedocument.h b/kate/part/katedocument.h
index 5c426761b..46e9e87f8 100644
--- a/kate/part/katedocument.h
+++ b/kate/part/katedocument.h
@@ -91,7 +91,7 @@ class KateDocument : public Kate::Document,
public:
KateDocument (bool bSingleViewMode=false, bool bBrowserView=false, bool bReadOnly=false,
- TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject * = 0, const char * = 0);
+ TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject * = 0, const char * = 0);
~KateDocument ();
bool closeURL();
diff --git a/kate/part/katehighlight.h b/kate/part/katehighlight.h
index 8bdc73b39..9cb4a62c6 100644
--- a/kate/part/katehighlight.h
+++ b/kate/part/katehighlight.h
@@ -213,7 +213,7 @@ class KateHighlighting
inline bool noHighlighting () const { return noHl; };
- // be carefull: all documents hl should be tqinvalidated after calling this method!
+ // be carefull: all documents hl should be invalidated after calling this method!
void dropDynamicContexts();
TQString indentation () { return m_indentation; }
@@ -377,7 +377,7 @@ class KateHlManager : public TQObject
uint countDynamicCtxs() { return dynamicCtxsCount; };
void setForceNoDCReset(bool b) { forceNoDCReset = b; };
- // be carefull: all documents hl should be tqinvalidated after having successfully called this method!
+ // be carefull: all documents hl should be invalidated after having successfully called this method!
bool resetDynamicCtxs();
signals:
diff --git a/kate/part/kateschema.cpp b/kate/part/kateschema.cpp
index 2b5e2342e..6b4f149fc 100644
--- a/kate/part/kateschema.cpp
+++ b/kate/part/kateschema.cpp
@@ -351,7 +351,7 @@ KateSchemaConfigColorTab::KateSchemaConfigColorTab( TQWidget *parent, const char
blay->addStretch();
// connect signal changed(); changed is emitted by a ColorButton change!
- connect( this, TQT_SIGNAL( changed() ), parent->tqparentWidget(), TQT_SLOT( slotChanged() ) );
+ connect( this, TQT_SIGNAL( changed() ), parent->parentWidget(), TQT_SLOT( slotChanged() ) );
// TQWhatsThis help
TQWhatsThis::add(m_back, i18n("<p>Sets the background color of the editing area.</p>"));
@@ -545,7 +545,7 @@ KateSchemaConfigFontTab::KateSchemaConfigFontTab( TQWidget *parent, const char *
m_fontchooser->enableColumn(KFontChooser::StyleList, false);
grid->addWidget( m_fontchooser, 0, 0);
- connect (this, TQT_SIGNAL( changed()), parent->tqparentWidget(), TQT_SLOT (slotChanged()));
+ connect (this, TQT_SIGNAL( changed()), parent->parentWidget(), TQT_SLOT (slotChanged()));
m_schema = -1;
}
@@ -599,7 +599,7 @@ KateSchemaConfigFontColorTab::KateSchemaConfigFontColorTab( TQWidget *parent, co
m_defaultStyles = new KateStyleListView( this, false );
grid->addWidget( m_defaultStyles, 0, 0);
- connect (m_defaultStyles, TQT_SIGNAL (changed()), parent->tqparentWidget(), TQT_SLOT (slotChanged()));
+ connect (m_defaultStyles, TQT_SIGNAL (changed()), parent->parentWidget(), TQT_SLOT (slotChanged()));
TQWhatsThis::add( m_defaultStyles, i18n(
"This list displays the default styles for the current schema and "
@@ -716,7 +716,7 @@ KateSchemaConfigHighlightTab::KateSchemaConfigHighlightTab( TQWidget *parent, co
"to edit from the popup menu.<p>You can unset the Background and Selected "
"Background colors from the context menu when appropriate.") );
- connect (m_styles, TQT_SIGNAL (changed()), parent->tqparentWidget(), TQT_SLOT (slotChanged()));
+ connect (m_styles, TQT_SIGNAL (changed()), parent->parentWidget(), TQT_SLOT (slotChanged()));
}
KateSchemaConfigHighlightTab::~KateSchemaConfigHighlightTab()
diff --git a/kate/part/kateschema.h b/kate/part/kateschema.h
index 4afd26255..566b6ea27 100644
--- a/kate/part/kateschema.h
+++ b/kate/part/kateschema.h
@@ -198,7 +198,7 @@ class KateSchemaConfigColorTab : public TQWidget
void schemaChanged( int newSchema );
signals:
- void changed(); // connected to tqparentWidget()->tqparentWidget() TQT_SLOT(slotChanged)
+ void changed(); // connected to parentWidget()->parentWidget() TQT_SLOT(slotChanged)
protected slots:
void slotMarkerColorChanged(const TQColor&);
@@ -223,7 +223,7 @@ class KateSchemaConfigFontTab : public TQWidget
void schemaChanged( int newSchema );
signals:
- void changed(); // connected to tqparentWidget()->tqparentWidget() TQT_SLOT(slotChanged)
+ void changed(); // connected to parentWidget()->parentWidget() TQT_SLOT(slotChanged)
private:
class KFontChooser *m_fontchooser;
diff --git a/kate/part/kateviewhelpers.cpp b/kate/part/kateviewhelpers.cpp
index 3f964e613..84eaca37c 100644
--- a/kate/part/kateviewhelpers.cpp
+++ b/kate/part/kateviewhelpers.cpp
@@ -244,7 +244,7 @@ class KateCmdLnWhatsThis : public TQWhatsThis
Kate::Command *cmd = KateCmd::self()->queryCommand( name );
if ( cmd )
{
- if ( cmd->help( (Kate::View*)m_parent->tqparentWidget(), name, s ) )
+ if ( cmd->help( (Kate::View*)m_parent->parentWidget(), name, s ) )
return beg + name + mid + s + end;
else
return beg + name + mid + i18n("No help for '%1'").arg( name ) + end;
@@ -380,7 +380,7 @@ void KateCmdLine::slotReturnPressed ( const TQString& text )
void KateCmdLine::hideMe () // unless i have focus ;)
{
- if ( isVisibleTo(tqparentWidget()) && ! hasFocus() ) {
+ if ( isVisibleTo(parentWidget()) && ! hasFocus() ) {
m_view->toggleCmdLine ();
}
}
diff --git a/kate/part/test_regression.cpp b/kate/part/test_regression.cpp
index ac1d8bdf5..9a2e88548 100644
--- a/kate/part/test_regression.cpp
+++ b/kate/part/test_regression.cpp
@@ -515,7 +515,7 @@ int main(int argc, char *argv[])
KateDocument *part = new KateDocument(/*bSingleViewMode*/true,
/*bBrowserView*/false,
/*bReadOnly*/false,
- /*tqparentWidget*/toplevel,
+ /*parentWidget*/toplevel,
/*widgetName*/"testkate");
part->readConfig(&cfg);
diff --git a/kate/part/katefactory.cpp b/kate/part/katefactory.cpp
index a9ccc7333..c42f698a3 100644
--- a/kate/part/katefactory.cpp
+++ b/kate/part/katefactory.cpp
@@ -48,7 +48,7 @@ class KateFactoryPublic : public KParts::Factory
public:
/**
* reimplemented create object method
* @param tqparentWidget parent widget
* @param widgetName widget name
* @param parent TQObject parent
* @param name object name
@@ -56,9 +56,9 @@ class KateFactoryPublic : public KParts::Factory
* @param args additional arguments
* @return constructed part object
*/
- KParts::Part *createPartObject ( TQWidget *tqparentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname, const TQStringList &args )
+ KParts::Part *createPartObject ( TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname, const TQStringList &args )
{
- return KateFactory::self()->createPartObject (tqparentWidget, widgetName, parent, name, classname, args);
+ return KateFactory::self()->createPartObject (parentWidget, widgetName, parent, name, classname, args);
}
};
@@ -206,14 +206,14 @@ KateFactory *KateFactory::self ()
return s_self;
}
-KParts::Part *KateFactory::createPartObject ( TQWidget *tqparentWidget, const char *widgetName, TQObject *parent, const char *name, const char *_classname, const TQStringList & )
+KParts::Part *KateFactory::createPartObject ( TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name, const char *_classname, const TQStringList & )
{
TQCString classname( _classname );
bool bWantSingleView = ( classname != "KTextEditor::Document" && classname != "Kate::Document" );
bool bWantBrowserView = ( classname == "Browser/View" );
bool bWantReadOnly = (bWantBrowserView || ( classname == "KParts::ReadOnlyPart" ));
- KParts::ReadWritePart *part = new KateDocument (bWantSingleView, bWantBrowserView, bWantReadOnly, tqparentWidget, widgetName, parent, name);
+ KParts::ReadWritePart *part = new KateDocument (bWantSingleView, bWantBrowserView, bWantReadOnly, parentWidget, widgetName, parent, name);
part->setReadWrite( !bWantReadOnly );
return part;
@@ -48,7 +48,7 @@ class KateFactoryPublic : public KParts::Factory
/**
* reimplemented create object method
- * @param tqparentWidget parent widget
+ * @param parentWidget parent widget
* @param widgetName widget name
* @param parent TQObject parent
diff --git a/kate/part/katefactory.h b/kate/part/katefactory.h
index 4c1ce0706..0fd939ce3 100644
--- a/kate/part/katefactory.h
+++ b/kate/part/katefactory.h
@@ -71,7 +71,7 @@ class KateFactory
/**
* reimplemented create object method
* @param tqparentWidget parent widget
* @param widgetName widget name
* @param parent TQObject parent
* @param name object name
@@ -79,7 +79,7 @@ class KateFactory
* @param args additional arguments
* @return constructed part object
*/
- KParts::Part *createPartObject ( TQWidget *tqparentWidget, const char *widgetName,
+ KParts::Part *createPartObject ( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name, const char *classname,
const TQStringList &args );
@@ -71,7 +71,7 @@ class KateFactory
/**
* reimplemented create object method
- * @param tqparentWidget parent widget
+ * @param parentWidget parent widget
* @param widgetName widget name
* @param parent TQObject parent